Sensitive

Struct Sensitive 

pub struct Sensitive<T>(pub(crate) T);
A wrapper type that marks the inner value as secret. This is used to prevent accidental logging of secrets by overriding the Debug and Display implementations to redact the value. This redaction can be bypassed by enabling the dangerous-crypto-debug feature.

Tuple Fields

0: T